@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from plone.app.content.interfaces import INameFromTitle
+from plone.base.utils import check_id
 from plone.i18n.normalizer import FILENAME_REGEX
 from plone.i18n.normalizer.interfaces import IURLNormalizer
 from plone.i18n.normalizer.interfaces import IUserPreferredURLNormalizer
-from zExceptions import BadRequest
 from zope.component import getUtility
 from zope.container.interfaces import INameChooser
 from zope.interface import implementer
 
-import six
 import time
 
 
@@ -18,7 +16,7 @@ ATTEMPTS = 100
 
 
 @implementer(INameChooser)
-class NormalizingNameChooser(object):
+class NormalizingNameChooser:
     """A name chooser for a Zope object manager.
 
     If the object is adaptable to or provides INameFromTitle, use the
@@ -38,17 +36,17 @@ class NormalizingNameChooser(object):
             if nameFromTitle is not None:
                 name = nameFromTitle.title
             if not name:
-                name = getattr(aq_base(obj), 'id', None)
+                name = getattr(aq_base(obj), "id", None)
             if not name:
-                name = getattr(aq_base(obj), 'portal_type', None)
+                name = getattr(aq_base(obj), "portal_type", None)
             if not name:
                 name = obj.__class__.__name__
 
-        if not isinstance(name, six.text_type):
-            name = six.text_type(name, 'utf-8')
-            #name = name.encode('utf-8')
+        if not isinstance(name, str):
+            name = str(name, "utf-8")
+            # name = name.encode('utf-8')
 
-        request = getattr(obj.__of__(container), 'REQUEST', None)
+        request = getattr(obj.__of__(container), "REQUEST", None)
         if request is not None:
             name = IUserPreferredURLNormalizer(request).normalize(name)
         else:
@@ -66,11 +64,11 @@ class NormalizingNameChooser(object):
         if not check_id(name, required=1):
             return name
 
-        ext = ''
+        ext = ""
         m = FILENAME_REGEX.match(name)
         if m is not None:
             name = m.groups()[0]
-            ext = '.' + m.groups()[1]
+            ext = "." + m.groups()[1]
 
         idx = 1
         while idx <= ATTEMPTS:
@@ -80,46 +78,29 @@ class NormalizingNameChooser(object):
             idx += 1
 
         # give one last attempt using the current date time before giving up
-        new_name = "%s-%s%s" % (name, time.time(), ext)
+        new_name = f"{name}-{time.time()}{ext}"
         if not check_id(new_name, required=1):
             return new_name
 
         raise ValueError(
-            "Cannot find a unique name based on %s after %d attemps." % (
+            "Cannot find a unique name based on %s after %d attemps."
+            % (
                 name,
                 ATTEMPTS,
             )
         )
 
     def _getCheckId(self, obj):
-        """Return a function that can act as the check_id script.
-        """
+        """Return a function that can act as the check_id script."""
         parent = aq_inner(self.context)
         # Check for a method or a skin script, like
         # Products/CMFPlone/skins/plone_scripts/check_id.py until Plone 5.1.
-        _check_id = getattr(obj, 'check_id', None)
+        _check_id = getattr(obj, "check_id", None)
 
         def do_Plone_check(newid, required):
             if _check_id is not None:
-                return _check_id(
-                    newid,
-                    required=required,
-                    contained_by=parent
-                )
+                return _check_id(newid, required=required, contained_by=parent)
 
-            # Function in CMFPlone added in 5.1.4/5,
-            # which replaces the skin script that will be removed in 5.2.
-            try:
-                from Products.CMFPlone.utils import check_id
-                return check_id(
-                    obj, newid, required=required, contained_by=parent)
-            except ImportError:
-                pass
-
-            # fallback to OFS
-            try:
-                parent._checkId(newid)
-            except BadRequest:
-                return True
+            return check_id(obj, newid, required=required, contained_by=parent)
 
         return do_Plone_check
