@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.content.browser import vocabulary
 from plone.app.content.browser.file import FileUploadView
 from plone.app.content.browser.query import QueryStringIndexOptions
@@ -12,8 +11,10 @@ from plone.app.testing import logout
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.app.testing import TEST_USER_NAME
+from plone.app.testing import TEST_USER_PASSWORD
 from plone.app.z3cform.interfaces import IFieldPermissionChecker
-from six.moves import range
+from Products.CMFCore.indexing import processQueue
+from unittest import mock
 from zope.component import getMultiAdapter
 from zope.component import provideAdapter
 from zope.component import provideUtility
@@ -28,40 +29,23 @@ import json
 import operator
 import os
 import transaction
-
-
-try:
-    from Products.CMFCore.indexing import processQueue
-except ImportError:
-    def processQueue():
-        pass
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+import unittest
 
 
 _dir = os.path.dirname(__file__)
 
-try:
-    import unittest2 as unittest
-except ImportError:  # pragma: nocover
-    import unittest  # pragma: nocover
-    assert unittest  # pragma: nocover
 
-
-class PermissionChecker(object):
+class PermissionChecker:
     def __init__(self, context):
         pass
 
     def validate(self, field_name, vocabulary_name=None):
-        if field_name == 'allowed_field':
+        if field_name == "allowed_field":
             return True
-        elif field_name == 'disallowed_field':
+        elif field_name == "disallowed_field":
             return False
         else:
-            raise AttributeError('Missing Field')
+            raise AttributeError("Missing Field")
 
 
 class ICustomPermissionProvider(Interface):
@@ -69,15 +53,19 @@ class ICustomPermissionProvider(Interface):
 
 
 def _enable_permission_checker(context):
-    provideAdapter(PermissionChecker, adapts=(ICustomPermissionProvider,),
-                   provides=IFieldPermissionChecker)
+    provideAdapter(
+        PermissionChecker,
+        adapts=(ICustomPermissionProvider,),
+        provides=IFieldPermissionChecker,
+    )
     alsoProvides(context, ICustomPermissionProvider)
 
 
 def _disable_permission_checker(context):
     noLongerProvides(context, ICustomPermissionProvider)
-    base.unregisterAdapter(required=(ICustomPermissionProvider,),
-                           provided=IFieldPermissionChecker)
+    base.unregisterAdapter(
+        required=(ICustomPermissionProvider,), provided=IFieldPermissionChecker
+    )
 
 
 class BrowserTest(unittest.TestCase):
@@ -85,173 +73,181 @@ class BrowserTest(unittest.TestCase):
     layer = PLONE_APP_CONTENT_DX_INTEGRATION_TESTING
 
     def setUp(self):
-        self.request = TestRequest(environ={'HTTP_ACCEPT_LANGUAGE': 'en'})
+        self.request = TestRequest(environ={"HTTP_ACCEPT_LANGUAGE": "en"})
         setRequest(self.request)
-        self.portal = self.layer['portal']
+        self.portal = self.layer["portal"]
         login(self.portal, TEST_USER_NAME)
-        setRoles(self.portal, TEST_USER_ID, ['Manager'])
-        provideUtility(ExampleVocabulary(), name=u'vocab_class')
-        provideUtility(ExampleFunctionVocabulary, name=u'vocab_function')
-        vocabulary.PERMISSIONS.update({
-            'vocab_class': 'Modify portal content',
-            'vocab_function': 'Modify portal content',
-        })
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
+        provideUtility(ExampleVocabulary(), name="vocab_class")
+        provideUtility(ExampleFunctionVocabulary, name="vocab_function")
+        vocabulary.PERMISSIONS.update(
+            {
+                "vocab_class": "Modify portal content",
+                "vocab_function": "Modify portal content",
+            }
+        )
 
     def testVocabularyQueryString(self):
-        """Test querying a class based vocabulary with a search string.
-        """
+        """Test querying a class based vocabulary with a search string."""
         view = VocabularyView(self.portal, self.request)
-        self.request.form.update({
-            'name': 'vocab_class',
-            'query': 'three'
-        })
+        self.request.form.update({"name": "vocab_class", "query": "three"})
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
+        self.assertEqual(len(data["results"]), 1)
 
     def testVocabularyFunctionQueryString(self):
-        """Test querying a function based vocabulary with a search string.
-        """
+        """Test querying a function based vocabulary with a search string."""
         view = VocabularyView(self.portal, self.request)
-        self.request.form.update({
-            'name': 'vocab_function',
-            'query': 'third'
-        })
+        self.request.form.update({"name": "vocab_function", "query": "third"})
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
+        self.assertEqual(len(data["results"]), 1)
 
     def testVocabularyNoResults(self):
-        """Tests that the widgets displays correctly
-        """
+        """Tests that the widgets displays correctly"""
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/foo'
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/foo",
                 }
             ]
         }
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query)
-        })
+        self.request.form.update(
+            {"name": "plone.app.vocabularies.Catalog", "query": json.dumps(query)}
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 0)
+        self.assertEqual(len(data["results"]), 0)
 
     def testVocabularyCatalogResults(self):
-        self.portal.invokeFactory('Document', id="page", title="page")
+        self.portal.invokeFactory("Document", id="page", title="page")
         self.portal.page.reindexObject()
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/plone'
-                }
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/plone",
+                },
+                {
+                    "i": "portal_type",
+                    "o": "plone.app.querystring.operation.selection.any",
+                    "v": "Document",
+                },
             ]
         }
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query),
-            'attributes': ['UID', 'id', 'title', 'path']
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Catalog",
+                "query": json.dumps(query),
+                "attributes": ["UID", "id", "title", "path"],
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
+        self.assertEqual(len(data["results"]), 1)
 
     def testVocabularyCatalogUnsafeMetadataAllowed(self):
         """Users with permission "Modify portal content" are allowed to see
         ``_unsafe_metadata``.
         """
-        self.portal.invokeFactory('Document', id="page", title="page")
+        self.portal.invokeFactory("Document", id="page", title="page")
         self.portal.page.reindexObject()
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/plone/page'
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/plone/page",
                 }
             ]
         }
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query),
-            'attributes': [
-                'id',
-                'commentors',
-                'Creator',
-                'listCreators',
-            ]
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Catalog",
+                "query": json.dumps(query),
+                "attributes": [
+                    "id",
+                    "commentors",
+                    "Creator",
+                    "listCreators",
+                ],
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(list(data['results'][0].keys())), 4)
+        self.assertEqual(len(list(data["results"][0].keys())), 4)
 
     def testVocabularyCatalogUnsafeMetadataDisallowed(self):
         """Users without permission "Modify portal content" are not allowed to
         see ``_unsafe_metadata``.
         """
-        self.portal.invokeFactory('Document', id="page", title="page")
+        self.portal.invokeFactory("Document", id="page", title="page")
         self.portal.page.reindexObject()
         # Downgrade permissions
         setRoles(self.portal, TEST_USER_ID, [])
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/plone/page'
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/plone/page",
                 }
             ]
         }
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query),
-            'attributes': [
-                'id',
-                'commentors',
-                'Creator',
-                'listCreators',
-            ]
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Catalog",
+                "query": json.dumps(query),
+                "attributes": [
+                    "id",
+                    "commentors",
+                    "Creator",
+                    "listCreators",
+                ],
+            }
+        )
         data = json.loads(view())
         # Only one result key should be returned, as ``commentors``,
         # ``Creator`` and ``listCreators`` is considered unsafe and thus
         # skipped.
-        self.assertEqual(len(list(data['results'][0].keys())), 1)
+        self.assertEqual(len(list(data["results"][0].keys())), 1)
 
     def testVocabularyBatching(self):
         amount = 30
         for i in range(amount):
-            self.portal.invokeFactory('Document', id="page" + str(i),
-                                      title="Page" + str(i))
-            self.portal['page' + str(i)].reindexObject()
+            self.portal.invokeFactory(
+                "Document", id="page" + str(i), title="Page" + str(i)
+            )
+            self.portal["page" + str(i)].reindexObject()
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/plone'
-                }
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/plone",
+                },
+                {
+                    "i": "portal_type",
+                    "o": "plone.app.querystring.operation.selection.any",
+                    "v": "Document",
+                },
             ]
         }
         # batch pages are 1-based
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query),
-            'attributes': ['UID', 'id', 'title', 'path'],
-            'batch': {
-                'page': '1',
-                'size': '10'
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Catalog",
+                "query": json.dumps(query),
+                "attributes": ["UID", "id", "title", "path"],
+                "batch": {"page": "1", "size": "10"},
             }
-        })
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 10)
-        self.assertEqual(data['total'], amount)
+        self.assertEqual(len(data["results"]), 10)
+        self.assertEqual(data["total"], amount)
 
     def testVocabularyEncoding(self):
         """The vocabulary should not return the binary encoded token
@@ -259,41 +255,39 @@ class BrowserTest(unittest.TestCase):
         set. Fixes an encoding problem. See:
         https://github.com/plone/Products.CMFPlone/issues/650
         """
-        test_val = u'Nåøï'
+        test_val = "Nåøï"
 
-        self.portal.invokeFactory('Document', id="page", title="page")
+        self.portal.invokeFactory("Document", id="page", title="page")
         self.portal.page.subject = (test_val,)
-        self.portal.page.reindexObject(idxs=['Subject'])
+        self.portal.page.reindexObject(idxs=["Subject"])
         processQueue()
 
-        self.request.form['name'] = 'plone.app.vocabularies.Keywords'
-        results = getMultiAdapter(
-            (self.portal, self.request),
-            name='getVocabulary'
-        )()
+        self.request.form["name"] = "plone.app.vocabularies.Keywords"
+        results = getMultiAdapter((self.portal, self.request), name="getVocabulary")()
         results = json.loads(results)
-        result = results['results'][0]
+        result = results["results"][0]
 
-        self.assertEqual(result['text'], test_val)
-        self.assertEqual(result['id'], test_val)
+        self.assertEqual(result["text"], test_val)
+        self.assertEqual(result["id"], test_val)
 
     def testVocabularyUnauthorized(self):
         setRoles(self.portal, TEST_USER_ID, [])
         view = VocabularyView(self.portal, self.request)
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Users',
-            'query': TEST_USER_NAME
-        })
+        self.request.form.update(
+            {"name": "plone.app.vocabularies.Users", "query": TEST_USER_NAME}
+        )
         data = json.loads(view())
-        self.assertEqual(data['error'], 'Vocabulary lookup not allowed')
+        self.assertEqual(data["error"], "Vocabulary lookup not allowed")
 
     def testVocabularyMissing(self):
         view = VocabularyView(self.portal, self.request)
-        self.request.form.update({
-            'name': 'vocabulary.that.does.not.exist',
-        })
+        self.request.form.update(
+            {
+                "name": "vocabulary.that.does.not.exist",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(data['error'], 'Vocabulary lookup not allowed')
+        self.assertEqual(data["error"], "Vocabulary lookup not allowed")
 
     def testPermissionCheckerAllowed(self):
         # Setup a custom permission checker on the portal
@@ -301,28 +295,33 @@ class BrowserTest(unittest.TestCase):
         view = VocabularyView(self.portal, self.request)
 
         # Allowed field is allowed
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.PortalTypes',
-            'field': 'allowed_field',
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.PortalTypes",
+                "field": "allowed_field",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']),
-                          len(self.portal.portal_types.objectIds()))
+        self.assertEqual(
+            len(data["results"]), len(self.portal.portal_types.objectIds())
+        )
         _disable_permission_checker(self.portal)
 
     def testPermissionCheckerUnknownVocab(self):
         _enable_permission_checker(self.portal)
         view = VocabularyView(self.portal, self.request)
         # Unknown vocabulary gives error
-        self.request.form.update({
-            'name': 'vocab.does.not.exist',
-            'field': 'allowed_field',
-        })
+        self.request.form.update(
+            {
+                "name": "vocab.does.not.exist",
+                "field": "allowed_field",
+            }
+        )
         data = json.loads(view())
         self.assertEqual(
-            data['error'],
-            'No factory with name "{}" exists.'.format(
-                'vocab.does.not.exist'))
+            data["error"],
+            'No factory with name "{}" exists.'.format("vocab.does.not.exist"),
+        )
         _disable_permission_checker(self.portal)
 
     def testPermissionCheckerDisallowed(self):
@@ -330,12 +329,14 @@ class BrowserTest(unittest.TestCase):
         view = VocabularyView(self.portal, self.request)
         # Disallowed field is not allowed
         # Allowed field is allowed
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.PortalTypes',
-            'field': 'disallowed_field',
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.PortalTypes",
+                "field": "disallowed_field",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(data['error'], 'Vocabulary lookup not allowed')
+        self.assertEqual(data["error"], "Vocabulary lookup not allowed")
         _disable_permission_checker(self.portal)
 
     def testPermissionCheckerShortCircuit(self):
@@ -343,23 +344,27 @@ class BrowserTest(unittest.TestCase):
         view = VocabularyView(self.portal, self.request)
         # Known vocabulary name short-circuits field permission check
         # global permission
-        self.request.form['name'] = 'plone.app.vocabularies.Users'
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Users',
-            'field': 'disallowed_field',
-        })
+        self.request.form["name"] = "plone.app.vocabularies.Users"
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Users",
+                "field": "disallowed_field",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(data['results'], [])
+        self.assertEqual(data["results"], [])
         _disable_permission_checker(self.portal)
 
     def testPermissionCheckerUnknownField(self):
         _enable_permission_checker(self.portal)
         view = VocabularyView(self.portal, self.request)
         # Unknown field is raises error
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.PortalTypes',
-            'field': 'missing_field',
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.PortalTypes",
+                "field": "missing_field",
+            }
+        )
         with self.assertRaises(AttributeError):
             view()
         _disable_permission_checker(self.portal)
@@ -371,8 +376,8 @@ class BrowserTest(unittest.TestCase):
         # Let's test that safe html is used on the fullname,
         # as alternative to the workaround in PloneHotfix20210518.
         for i in range(amount):
-            id = 'user' + str(i)
-            acl_users.userFolderAddUser(id, 'secret', ['Member'], [])
+            id = "user" + str(i)
+            acl_users.userFolderAddUser(id, TEST_USER_PASSWORD, ["Member"], [])
             member = membership.getMemberById(id)
             # Make user0 the hacker.
             if i == 0:
@@ -381,17 +386,16 @@ class BrowserTest(unittest.TestCase):
                 fullname = id
             member.setMemberProperties(mapping={"fullname": fullname})
         view = VocabularyView(self.portal, self.request)
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Users',
-            'query': 'user'
-        })
+        self.request.form.update(
+            {"name": "plone.app.vocabularies.Users", "query": "user"}
+        )
         data = json.loads(view())
 
-        self.assertEqual(len(data['results']), amount)
+        self.assertEqual(len(data["results"]), amount)
         # Let's sort, just to be sure.
-        results = sorted(data['results'], key=operator.itemgetter("id"))
+        results = sorted(data["results"], key=operator.itemgetter("id"))
         # The first one is the hacker.  The hack should have failed.
-        self.assertDictEqual(results[0], {'id': 'user0', 'text': 'user  hacker'})
+        self.assertDictEqual(results[0], {"id": "user0", "text": "user  hacker"})
 
     def testSource(self):
         from z3c.form.browser.text import TextWidget
@@ -401,9 +405,9 @@ class BrowserTest(unittest.TestCase):
         from zope.schema.interfaces import ISource
 
         @implementer(ISource)
-        class DummyCatalogSource(object):
+        class DummyCatalogSource:
             def search_catalog(self, query):
-                querytext = query['SearchableText']['query']
+                querytext = query["SearchableText"]["query"]
                 return [mock.Mock(id=querytext)]
 
         widget = TextWidget(self.request)
@@ -412,23 +416,26 @@ class BrowserTest(unittest.TestCase):
         widget.field.interface = Interface
 
         from plone.app.content.browser.vocabulary import SourceView
+
         view = SourceView(widget, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'SearchableText',
-                    'o': 'plone.app.querystring.operation.string.is',
-                    'v': 'foo'
+                    "i": "SearchableText",
+                    "o": "plone.app.querystring.operation.string.is",
+                    "v": "foo",
                 }
             ]
         }
-        self.request.form.update({
-            'query': json.dumps(query),
-            'attributes': 'id',
-        })
+        self.request.form.update(
+            {
+                "query": json.dumps(query),
+                "attributes": "id",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
-        self.assertEqual(data['results'][0]['id'], 'foo')
+        self.assertEqual(len(data["results"]), 1)
+        self.assertEqual(data["results"][0]["id"], "foo")
 
     def testSourceCollectionField(self):
         # This test uses a collection field
@@ -437,12 +444,13 @@ class BrowserTest(unittest.TestCase):
         from z3c.form.browser.text import TextWidget
         from zope.interface import implementer
         from zope.interface import Interface
-        from zope.schema import List, Choice
+        from zope.schema import Choice
+        from zope.schema import List
         from zope.schema.interfaces import ISource
         from zope.schema.vocabulary import SimpleTerm
 
         @implementer(ISource)
-        class DummySource(object):
+        class DummySource:
             def search(self, query):
                 terms = [SimpleTerm(query, query)]
                 return iter(terms)
@@ -453,25 +461,28 @@ class BrowserTest(unittest.TestCase):
         widget.field.interface = Interface
 
         from plone.app.content.browser.vocabulary import SourceView
+
         view = SourceView(widget, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'SearchableText',
-                    'o': 'plone.app.querystring.operation.string.is',
-                    'v': 'foo'
+                    "i": "SearchableText",
+                    "o": "plone.app.querystring.operation.string.is",
+                    "v": "foo",
                 }
             ],
-            'sort_on': 'id',
-            'sort_order': 'ascending',
+            "sort_on": "id",
+            "sort_order": "ascending",
         }
-        self.request.form.update({
-            'query': json.dumps(query),
-            'batch': json.dumps({'size': 10, 'page': 1}),
-        })
+        self.request.form.update(
+            {
+                "query": json.dumps(query),
+                "batch": json.dumps({"size": 10, "page": 1}),
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
-        self.assertEqual(data['results'][0]['id'], 'foo')
+        self.assertEqual(len(data["results"]), 1)
+        self.assertEqual(data["results"][0]["id"], "foo")
 
     def testSourcePermissionDenied(self):
         from z3c.form.browser.text import TextWidget
@@ -481,9 +492,9 @@ class BrowserTest(unittest.TestCase):
         from zope.schema.interfaces import ISource
 
         @implementer(ISource)
-        class DummyCatalogSource(object):
+        class DummyCatalogSource:
             def search_catalog(self, query):
-                querytext = query['SearchableText']['query']
+                querytext = query["SearchableText"]["query"]
                 return [mock.Mock(id=querytext)]
 
         widget = TextWidget(self.request)
@@ -492,22 +503,25 @@ class BrowserTest(unittest.TestCase):
         widget.field.interface = Interface
 
         from plone.app.content.browser.vocabulary import SourceView
+
         view = SourceView(widget, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'SearchableText',
-                    'o': 'plone.app.querystring.operation.string.is',
-                    'v': 'foo'
+                    "i": "SearchableText",
+                    "o": "plone.app.querystring.operation.string.is",
+                    "v": "foo",
                 }
             ]
         }
-        self.request.form.update({
-            'query': json.dumps(query),
-        })
+        self.request.form.update(
+            {
+                "query": json.dumps(query),
+            }
+        )
         logout()
         data = json.loads(view())
-        self.assertEqual(data['error'], 'Vocabulary lookup not allowed.')
+        self.assertEqual(data["error"], "Vocabulary lookup not allowed.")
 
     def testSourceDefaultPermission(self):
         from plone.app.content.browser.vocabulary import SourceView
@@ -536,7 +550,7 @@ class BrowserTest(unittest.TestCase):
         from zope.schema.interfaces import ISource
 
         @implementer(ISource)
-        class DummyCatalogSource(object):
+        class DummyCatalogSource:
             def search(self, query):
                 return [mock.Mock(value=mock.Mock(id=query))]
 
@@ -546,67 +560,81 @@ class BrowserTest(unittest.TestCase):
         widget.field.interface = Interface
 
         from plone.app.content.browser.vocabulary import SourceView
+
         view = SourceView(widget, self.request)
-        self.request.form.update({
-            'query': 'foo',
-            'attributes': 'id',
-        })
+        self.request.form.update(
+            {
+                "query": "foo",
+                "attributes": "id",
+            }
+        )
         data = json.loads(view())
-        self.assertEqual(len(data['results']), 1)
-        self.assertEqual(data['results'][0]['id'], 'foo')
+        self.assertEqual(len(data["results"]), 1)
+        self.assertEqual(data["results"][0]["id"], "foo")
 
     def testQueryStringConfiguration(self):
         view = QueryStringIndexOptions(self.portal, self.request)
         data = json.loads(view())
         # just test one so we know it's working...
-        self.assertEqual(data['indexes']['sortable_title']['sortable'], True)
+        self.assertEqual(data["indexes"]["sortable_title"]["sortable"], True)
 
-    @mock.patch('zope.i18n.negotiate', new=lambda ctx: 'de')
+    @mock.patch("zope.i18n.negotiate", new=lambda ctx: "de")
     def testUntranslatableMetadata(self):
         """Test translation of ``@@getVocabulary`` view results.
         From the standard metadata columns, only ``Type`` is translated.
         """
         # Language is set via language negotiaton patch.
 
-        self.portal.invokeFactory('Document', id="page", title="page")
+        self.portal.invokeFactory("Document", id="page", title="page")
         self.portal.page.reindexObject()
         view = VocabularyView(self.portal, self.request)
         query = {
-            'criteria': [
+            "criteria": [
                 {
-                    'i': 'path',
-                    'o': 'plone.app.querystring.operation.string.path',
-                    'v': '/plone/page'
+                    "i": "path",
+                    "o": "plone.app.querystring.operation.string.path",
+                    "v": "/plone/page",
                 }
             ]
         }
-        self.request.form.update({
-            'name': 'plone.app.vocabularies.Catalog',
-            'query': json.dumps(query),
-            'attributes': [
-                'id',
-                'portal_type',
-                'Type',
-            ]
-        })
+        self.request.form.update(
+            {
+                "name": "plone.app.vocabularies.Catalog",
+                "query": json.dumps(query),
+                "attributes": [
+                    "id",
+                    "portal_type",
+                    "Type",
+                ],
+            }
+        )
 
         # data['results'] should return one item, which represents the document
         # created before.
         data = json.loads(view())
 
         # Type is translated
-        self.assertEqual(data['results'][0]['Type'], u'Seite')
+        self.assertEqual(data["results"][0]["Type"], "Seite")
 
         # portal_type is never translated
-        self.assertEqual(data['results'][0]['portal_type'], u'Document')
+        self.assertEqual(data["results"][0]["portal_type"], "Document")
 
     def testGetMimeIcon(self):
-        """ Check if the returned icon is correct
-        """
+        """Check if the returned icon is correct"""
+        query = {
+            "criteria": [
+                {
+                    "i": "portal_type",
+                    "o": "plone.app.querystring.operation.selection.any",
+                    "v": "File",
+                },
+            ]
+        }
         self.request.form.update(
             {
                 "name": "plone.app.vocabularies.Catalog",
                 "attributes": ["getMimeIcon"],
+                "query": json.dumps(query),
             }
         )
         view = VocabularyView(self.portal, self.request)
@@ -616,9 +644,7 @@ class BrowserTest(unittest.TestCase):
         obj = self.portal["my-file"]
         obj.reindexObject()
 
-        self.assertListEqual(
-            json.loads(view())["results"], [{"getMimeIcon": None}]
-        )
+        self.assertListEqual(json.loads(view())["results"], [{"getMimeIcon": None}])
 
         # mock a pdf
         obj.file = mock.Mock(contentType="application/pdf")
@@ -636,6 +662,7 @@ class BrowserTest(unittest.TestCase):
             [{"getMimeIcon": "/plone/++resource++mimetype.icons/unknown.png"}],
         )
 
+
 class FunctionalBrowserTest(unittest.TestCase):
 
     layer = PLONE_APP_CONTENT_DX_FUNCTIONAL_TESTING
@@ -643,38 +670,40 @@ class FunctionalBrowserTest(unittest.TestCase):
     def setUp(self):
         self.request = TestRequest()
         setRequest(self.request)
-        self.portal = self.layer['portal']
+        self.portal = self.layer["portal"]
         login(self.portal, TEST_USER_NAME)
-        setRoles(self.portal, TEST_USER_ID, ['Manager'])
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
 
     def testFileUpload(self):
         view = FileUploadView(self.portal, self.request)
         from plone.namedfile.file import FileChunk
-        chunk = FileChunk(b'foobar')
-        chunk.filename = 'test.xml'
-        self.request.form['file'] = chunk
-        self.request.REQUEST_METHOD = 'POST'
+
+        chunk = FileChunk(b"foobar")
+        chunk.filename = "test.xml"
+        self.request.form["file"] = chunk
+        self.request.REQUEST_METHOD = "POST"
         # the next calls plone.app.dexterity.factories and does a
         # transaction.commit. Needs cleanup and FunctionalTesting layer.
         data = json.loads(view())
-        self.assertEqual(data['url'], 'http://nohost/plone/test.xml')
-        self.assertTrue(data['UID'] is not None)
+        self.assertEqual(data["url"], "http://nohost/plone/test.xml")
+        self.assertTrue(data["UID"] is not None)
         # clean it up...
-        self.portal.manage_delObjects(['test.xml'])
+        self.portal.manage_delObjects(["test.xml"])
         transaction.commit()
 
     def testFileUploadTxt(self):
         view = FileUploadView(self.portal, self.request)
         from plone.namedfile.file import FileChunk
-        chunk = FileChunk(b'foobar')
-        chunk.filename = 'test.txt'
-        self.request.form['file'] = chunk
-        self.request.REQUEST_METHOD = 'POST'
+
+        chunk = FileChunk(b"foobar")
+        chunk.filename = "test.txt"
+        self.request.form["file"] = chunk
+        self.request.REQUEST_METHOD = "POST"
         # the next calls plone.app.dexterity.factories and does a
         # transaction.commit. Needs cleanup and FunctionalTesting layer.
         data = json.loads(view())
-        self.assertEqual(data['url'], 'http://nohost/plone/test.txt')
-        self.assertTrue(data['UID'] is not None)
+        self.assertEqual(data["url"], "http://nohost/plone/test.txt")
+        self.assertTrue(data["UID"] is not None)
         # clean it up...
-        self.portal.manage_delObjects(['test.txt'])
+        self.portal.manage_delObjects(["test.txt"])
         transaction.commit()
